#delimit ;
clear all;

use "p01i6.dta", clear;

*************************************************
* WEIGHTS FOR TABULATION
*************************************************;
gen simpwt = X42001/5;

*************************************************
* AGE CATEGORIES
*************************************************;
gen age_2028 = (X14>=20 & X14<=28) if !missing(X14);
gen age_2937 = (X14>=29 & X14<=37) if !missing(X14);
gen age_3846 = (X14>=38 & X14<=46) if !missing(X14);
gen age_4755 = (X14>=47 & X14<=55) if !missing(X14);
gen age_5664 = (X14>=56 & X14<=64) if !missing(X14);
gen age_6573 = (X14>=65 & X14<=73) if !missing(X14);
gen age_7482 = (X14>=74 & X14<=82) if !missing(X14);

gen age_cat = 0 if age_2028==1|age_2937==1|age_3846==1|age_4755==1|age_5664==1|age_6573==1|age_7482==1;
replace age_cat = 1 if age_2937==1;
replace age_cat = 2 if age_3846==1;
replace age_cat = 3 if age_4755==1;
replace age_cat = 4 if age_5664==1;
replace age_cat = 5 if age_6573==1;
replace age_cat = 6 if age_7482==1;

label define agegp 0 "20-28" 1 "29-37" 2 "38-46" 3 "47-55" 4 "56-64" 5 "65-73" 6 "74-82";
label values age_cat agegp;


*************************************************
* RETIREMENT ACCOUNT PARTICIPATION
*************************************************;
* Individual Retirement Accounts (IRAs);
gen haveIRA = 0;
replace haveIRA = 1 if X6444==1|X6448==1 | X6446==1|X6450==1 | X6447==1|X6451==1;

* Defined Contribution Plans;
gen haveDC = 0;
replace haveDC = 1 if inrange(X4216,1,2)|X4216==7|inrange(X4216,11,12)|X4216==18
					 |inrange(X4316,1,2)|X4316==7|inrange(X4316,11,12)|X4316==18
					 |inrange(X4416,1,2)|X4416==7|inrange(X4416,11,12)|X4416==18
					 |inrange(X4816,1,2)|X4816==7|inrange(X4816,11,12)|X4816==18
					 |inrange(X4916,1,2)|X4916==7|inrange(X4916,11,12)|X4916==18
					 |inrange(X5016,1,2)|X5016==7|inrange(X5016,11,12)|X5016==18
					 |X4436!=0|X5036!=0					 
					 |(inrange(X5316,1,2)&X6461==1)|(inrange(X5324,1,2)&X6466==1)
					 |(inrange(X5332,1,2)&X6471==1)|(inrange(X5416,1,2)&X6476==1)
					 |(inrange(X5424,1,2)&X6481==1)|(inrange(X5432,1,2)&X6486==1)
					 |X5603==2|X5611==2|X5619==2|X5627==2|X5635==2|X5643==2
					 |X5603==3|X5611==3|X5619==3|X5627==3|X5635==2|X5643==2
					 |X3605==1|X3615==1;

* Defined Benefit Plans;
gen haveDB = 0;
replace haveDB = 1 if X4203==1|X4203==3|X4303==1|X4303==3|X4403==1|X4403==3
					 |X4803==1|X4803==3|X4903==1|X4903==3|X5003==1|X5003==3
					 |(inrange(X5316,1,2)&X6461==5)|(inrange(X5324,1,2)&X6466==5)
					 |(inrange(X5332,1,2)&X6471==5)|(inrange(X5416,1,2)&X6476==5)
					 |(inrange(X5424,1,2)&X6481==5)|(inrange(X5432,1,2)&X6486==5)
					 |X5603==1|X5603==3|X5611==1|X5611==3|X5619==1|X5619==3
					 |X5627==1|X5627==3|X5635==1|X5635==3|X5643==1|X5643==3;

gen haveAny = haveIRA|haveDC|haveDB;

**************************************************************************************************
* % TABLE 12: REPEATED CROSS-SECTION EVIDENCE ON EVOLUTION OF RETIREMENT PLAN PARTICIPATION, 2001
**************************************************************************************************;
table age_cat [pw=simpwt], c(mean haveDC mean haveDB mean haveAny);
